@@ -1,33 +1,30 @@
 #!/usr/bin/perl
 
-package JSON::RPC::Common::Procedure::Return::Version_2_0;
-BEGIN {
-  $JSON::RPC::Common::Procedure::Return::Version_2_0::VERSION = '0.10';
-}
+package JSON::RPC::Common::Procedure::Return::Version_1_1;
+$JSON::RPC::Common::Procedure::Return::Version_1_1::VERSION = '0.11';
 use Moose;
-# ABSTRACT: JSON-RPC 2.0 Procedure Return
+# ABSTRACT: JSON-RPC 1.1 Procedure Return
 
-use JSON::RPC::Common::Procedure::Return::Version_2_0::Error;
+use JSON::RPC::Common::Procedure::Return::Version_1_1::Error;
 
 use namespace::clean -except => [qw(meta)];
 
 extends qw(JSON::RPC::Common::Procedure::Return);
 
 has '+version' => (
-	# default => "2.0", # broken, Moose::Meta::Method::Accessor gens numbers if looks_like_number
-	default => sub { "2.0" },
-	# init_arg => "jsonrpc", # illegal inherit arg. bah. it's meaningless, so we don't care
+	# default => "1.1", # broken, Moose::Meta::Method::Accessor gens numbers if looks_like_number
+	default => sub { "1.1" },
 );
 
 has '+error_class' => (
-	default => "JSON::RPC::Common::Procedure::Return::Version_2_0::Error",
+	default => "JSON::RPC::Common::Procedure::Return::Version_1_1::Error",
 );
 
 sub deflate {
 	my $self = shift;
 
 	return {
-		jsonrpc => "2.0",
+		version => "1.1",
 		( $self->has_error
 			? ( error => $self->deflate_error )
 			: ( result  => $self->result ) ),
@@ -39,19 +36,17 @@ __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
 
-
-
-
 __END__
+
 =pod
 
 =head1 NAME
 
-JSON::RPC::Common::Procedure::Return::Version_2_0 - JSON-RPC 2.0 Procedure Return
+JSON::RPC::Common::Procedure::Return::Version_1_1 - JSON-RPC 1.1 Procedure Return
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -59,7 +54,7 @@ version 0.10
 
 =head1 DESCRIPTION
 
-This class implements procedure returns for JSON::RPC 2.0.
+This class implements procedure returns for JSON::RPC 1.1.
 
 See L<JSON::RPC::Common::Procedure::Return>.
 
@@ -69,10 +64,9 @@ Yuval Kogman <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yuval Kogman.
+This software is copyright (c) 2014 by Yuval Kogman and others.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
